==> zio-aws-chimesdkmediapipelines_3-5.20.32.2-sources.jar: zio/aws/chimesdkmediapipelines/model/MediaInsightsPipelineConfigurationElementType.scala <==
package zio.aws.chimesdkmediapipelines.model
import scala.jdk.CollectionConverters.*
sealed trait MediaInsightsPipelineConfigurationElementType {
  def unwrap: software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType
}
object MediaInsightsPipelineConfigurationElementType {
  def wrap(
      value: software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType
  ): zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
    value match {
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.AMAZON_TRANSCRIBE_CALL_ANALYTICS_PROCESSOR =>
        val r = AmazonTranscribeCallAnalyticsProcessor
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.VOICE_ANALYTICS_PROCESSOR =>
        val r = VoiceAnalyticsProcessor
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.AMAZON_TRANSCRIBE_PROCESSOR =>
        val r = AmazonTranscribeProcessor
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.KINESIS_DATA_STREAM_SINK =>
        val r = KinesisDataStreamSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.LAMBDA_FUNCTION_SINK =>
        val r = LambdaFunctionSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.SQS_QUEUE_SINK =>
        val r = SqsQueueSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.SNS_TOPIC_SINK =>
        val r = SnsTopicSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.S3_RECORDING_SINK =>
        val r = S3RecordingSink
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.UNKNOWN_TO_SDK_VERSION
  }
  case object AmazonTranscribeCallAnalyticsProcessor
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.AMAZON_TRANSCRIBE_CALL_ANALYTICS_PROCESSOR
  }
  case object VoiceAnalyticsProcessor
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.VOICE_ANALYTICS_PROCESSOR
  }
  case object AmazonTranscribeProcessor
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.AMAZON_TRANSCRIBE_PROCESSOR
  }
  case object KinesisDataStreamSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.KINESIS_DATA_STREAM_SINK
  }
  case object LambdaFunctionSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.LAMBDA_FUNCTION_SINK
  }
  case object SqsQueueSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.SQS_QUEUE_SINK
  }
  case object SnsTopicSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.SNS_TOPIC_SINK
  }
  case object S3RecordingSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.S3_RECORDING_SINK
  }
}

==> zio-aws-chimesdkmediapipelines_3-6.20.162.1-sources.jar: zio/aws/chimesdkmediapipelines/model/MediaInsightsPipelineConfigurationElementType.scala <==
package zio.aws.chimesdkmediapipelines.model
import scala.jdk.CollectionConverters.*
sealed trait MediaInsightsPipelineConfigurationElementType {
  def unwrap: software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType
}
object MediaInsightsPipelineConfigurationElementType {
  def wrap(
      value: software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType
  ): zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
    value match {
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.AMAZON_TRANSCRIBE_CALL_ANALYTICS_PROCESSOR =>
        val r = AmazonTranscribeCallAnalyticsProcessor
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.VOICE_ANALYTICS_PROCESSOR =>
        val r = VoiceAnalyticsProcessor
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.AMAZON_TRANSCRIBE_PROCESSOR =>
        val r = AmazonTranscribeProcessor
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.KINESIS_DATA_STREAM_SINK =>
        val r = KinesisDataStreamSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.LAMBDA_FUNCTION_SINK =>
        val r = LambdaFunctionSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.SQS_QUEUE_SINK =>
        val r = SqsQueueSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.SNS_TOPIC_SINK =>
        val r = SnsTopicSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.S3_RECORDING_SINK =>
        val r = S3RecordingSink
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.VOICE_ENHANCEMENT_SINK =>
        val r = VoiceEnhancementSink
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.UNKNOWN_TO_SDK_VERSION
  }
  case object AmazonTranscribeCallAnalyticsProcessor
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.AMAZON_TRANSCRIBE_CALL_ANALYTICS_PROCESSOR
  }
  case object VoiceAnalyticsProcessor
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.VOICE_ANALYTICS_PROCESSOR
  }
  case object AmazonTranscribeProcessor
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.AMAZON_TRANSCRIBE_PROCESSOR
  }
  case object KinesisDataStreamSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.KINESIS_DATA_STREAM_SINK
  }
  case object LambdaFunctionSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.LAMBDA_FUNCTION_SINK
  }
  case object SqsQueueSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.SQS_QUEUE_SINK
  }
  case object SnsTopicSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.SNS_TOPIC_SINK
  }
  case object S3RecordingSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.S3_RECORDING_SINK
  }
  case object VoiceEnhancementSink
      extends zio.aws.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaInsightsPipelineConfigurationElementType.VOICE_ENHANCEMENT_SINK
  }
}
